@@ -182,23 +182,28 @@ class TimeBasedDatabaseTable(DatabaseTable):
             - start_time and end_time, then duration won't be used
             - start_time and duration, then end_time is start_time + duration
             - end_time and duration, then start_time is end_time - duration
-            - only duration, then a default end_time of now is used
+            - only duration, then a default end_time of now is used. if duration is None, then return all entries in
+                the database disregarding a start or end time
 
         Example of how this might be implemented:
-            if start_time is None and end_time is None:
-                end_time = datetime.now()
+            if duration is not None:
+                if start_time is None and end_time is None:
+                    end_time = datetime.now()
 
-            if start_time and end_time:
-                pass
-            elif start_time:
-                end_time = start_time + duration
-            elif end_time:
-                start_time = end_time - duration
-            command = self._select_query + " WHERE datetime BETWEEN :start_time AND :end_time"
-            values = {
-                'start_time': start_time,
-                'end_time': end_time,
-            }
+                if start_time and end_time:
+                    pass
+                elif start_time:
+                    end_time = start_time + duration
+                elif end_time:
+                    start_time = end_time - duration
+                command = self._select_query + " WHERE datetime BETWEEN :start_time AND :end_time"
+                values = {
+                    'start_time': start_time,
+                    'end_time': end_time,
+                }
+            else:
+                command = self._select_query
+                values = {}
             with sqlite3.connect(self.file_path) as db:
                 with closing(db.cursor()) as cur:
                     cur.execute(command, values)
