@@ -324,6 +324,19 @@ class TestConfiguredAction(unittest.TestCase):
         self.assertEqual(track_2.status_code, 3)
         self.assertEqual(track_2.action_return, 'metal', "ensure that the action executed")
 
+    def test_configuration_removal(self):
+        """tests removal of a configuration from list"""
+        def temporary_action():
+            """a temporary action to register"""
+            return
+        ca = ConfiguredAction(temporary_action, parent_identifier_override='custom parent id')
+        self.assertTrue(ca in ConfiguredAction.class_registry, 'ensure action was registered')
+        # attempt to remove configured action from registry
+        ConfiguredAction.remove_configuration_from_registry(ca.name)
+        self.assertTrue(ca in ConfiguredAction.class_registry, 'ensure removal failed due to parent id mismatch')
+        ConfiguredAction.remove_configuration_from_registry(ca.name, parent_identifier='custom parent id')
+        self.assertFalse(ca in ConfiguredAction.class_registry, 'ensure configured action was removed')
+
 
 class TestEvalAction(unittest.TestCase):
     def setUp(self) -> None:
